FasterPayment

Struct FasterPayment 

pub struct FasterPayment {
Show 26 fields pub faster_payment: StringBoolean, pub fps_fpid: String, pub fps_payment_id: String, pub insertion: String, pub standin_correlation_id: String, pub trn: String, pub ledger_details: LedgerDetails, pub client_idempotency_key: Option<String>, pub confirmation_of_payee_decision_id: Option<String>, pub confirmation_of_payee_requester_id: Option<String>, pub money_transfer_id: Option<String>, pub money_transfer_originating_id: Option<String>, pub duplicate_payment_prompt_enabled: Option<StringBoolean>, pub outbound_payment_trace_id: Option<String>, pub payment_source: Option<PaymentSource>, pub device_fingerprint: Option<String>, pub coach_detected: Option<StringBoolean>, pub faster_payment_initiator: Option<FasterPaymentInitiator>, pub fps_trn: Option<String>, pub share_detected: Option<StringBoolean>, pub notification_on_settle: Option<StringBoolean>, pub series_id: Option<String>, pub series_iteration_count: Option<String>, pub hold_decision: Option<HoldDecision>, pub action_code: Option<String>, pub extra: ExtraValues,
}
A Faster Payments transaction

Fields

faster_payment: StringBooleanfps_fpid: Stringfps_payment_id: Stringinsertion: Stringstandin_correlation_id: Stringtrn: Stringledger_details: LedgerDetailsclient_idempotency_key: Option<String>confirmation_of_payee_decision_id: Option<String>confirmation_of_payee_requester_id: Option<String>money_transfer_id: Option<String>money_transfer_originating_id: Option<String>duplicate_payment_prompt_enabled: Option<StringBoolean>outbound_payment_trace_id: Option<String>payment_source: Option<PaymentSource>device_fingerprint: Option<String>coach_detected: Option<StringBoolean>faster_payment_initiator: Option<FasterPaymentInitiator>fps_trn: Option<String>share_detected: Option<StringBoolean>notification_on_settle: Option<StringBoolean>series_id: Option<String>

Present when on a potential series of recurring payments

series_iteration_count: Option<String>

Present when on a potential series of recurring payments

hold_decision: Option<HoldDecision>action_code: Option<String>extra: ExtraValues

The value had extra fields that weren’t parsed into another field.