pub enum LedgerEntryIntent {
FlexRepayment,
FlexTransferMoney,
SomethingElse(String),
}Variants
FlexRepayment
Money is transferred to the Flex account as part of a repayment
FlexTransferMoney
Money is transferred from the Flex account to the regular bank account
SomethingElse(String)
The value didn’t match anything currently parsed.