MerchantTransaction

Struct MerchantTransaction 

pub struct MerchantTransaction {
Show 21 fields pub mcc: String, pub token_transaction_identifier: Option<String>, pub tokenization_method: Option<String>, pub token_unique_reference: Option<String>, pub transaction_description_localised: StringBoolean, pub transaction_locale_country: String, pub standin_correlation_id: String, pub mastercard_lifecycle_id: String, pub mastercard_approval_type: Option<MastercardApprovalType>, pub mastercard_auth_message_id: String, pub mastercard_card_id: String, pub mastercard_clearing_message_id: Option<String>, pub mastercard_partial_approval_supported: Option<StringBoolean>, pub card_acceptor_contact_number: Option<String>, pub card_acceptor_website: Option<String>, pub coin_jar_transaction: Option<String>, pub hide_amount: Option<StringBoolean>, pub hide_transaction: Option<StringBoolean>, pub auth_account_id: Option<String>, pub ledger_details: LedgerDetails, pub extra: ExtraValues,
}

Fields

mcc: Stringtoken_transaction_identifier: Option<String>

Seems to only be present for transactions made via NFC, i.e. Google Pay, Apple Pay, Samsung Wallet, etc.

tokenization_method: Option<String>

Seems to only be present for transactions made via NFC, i.e. Google Pay, Apple Pay, Samsung Wallet, etc.

token_unique_reference: Option<String>

Seems to only be present for transactions made via NFC, i.e. Google Pay, Apple Pay, Samsung Wallet, etc.

transaction_description_localised: StringBooleantransaction_locale_country: Stringstandin_correlation_id: Stringmastercard_lifecycle_id: Stringmastercard_approval_type: Option<MastercardApprovalType>mastercard_auth_message_id: Stringmastercard_card_id: Stringmastercard_clearing_message_id: Option<String>

Set once the transaction has been cleared, often the next working day

mastercard_partial_approval_supported: Option<StringBoolean>

This field is present (and StringBoolean::True) when the transaction is approved to be reduced later, for example fuel pay-at-pump transactions.

card_acceptor_contact_number: Option<String>

Present during online transactions

card_acceptor_website: Option<String>

Present during online transactions

coin_jar_transaction: Option<String>

The ID of the transaction if you decide to round up into a savings account

hide_amount: Option<StringBoolean>hide_transaction: Option<StringBoolean>auth_account_id: Option<String>ledger_details: LedgerDetailsextra: ExtraValues

The value had extra fields that weren’t parsed into another field.