pub struct WebhookData {Show 37 fields
pub id: String,
pub created: DateTime<Utc>,
pub description: String,
pub amount: i64,
pub currency: String,
pub is_load: bool,
pub settled: SettledTimestamp,
pub local_amount: i64,
pub local_currency: String,
pub merchant: Option<Merchant>,
pub merchant_feedback_uri: String,
pub notes: String,
pub metadata: WebhookMetadata,
pub category: String,
pub updated: DateTime<Utc>,
pub account_id: String,
pub user_id: String,
pub counterparty: CounterpartyOrNone,
pub scheme: Scheme,
pub dedupe_id: String,
pub originator: bool,
pub include_in_spending: bool,
pub can_be_excluded_from_breakdown: bool,
pub can_be_made_subscription: bool,
pub can_split_the_bill: bool,
pub can_add_to_tab: bool,
pub can_match_transactions_in_categorization: bool,
pub amount_is_pending: bool,
pub parent_account_id: String,
pub categories: Option<HashMap<String, i64>>,
pub declined: Option<Decline>,
pub attachments: (),
pub atm_fees_detailed: (),
pub fees: HashMap<(), ()>,
pub international: (),
pub labels: (),
pub extra: ExtraValues,
}Fields
id: Stringcreated: DateTime<Utc>description: Stringamount: i64The amount of money in the transaction, in whole pence (or equivalent for foreign currency)
currency: StringThe ISO 4127 currency code of Self::amount
is_load: boolsettled: SettledTimestamplocal_amount: i64The amount of money in the transaction, in whole pence (or equivalent for foreign currency)
local_currency: StringThe ISO 4127 currency code of Self::local_amount
merchant: Option<Merchant>merchant_feedback_uri: Stringnotes: Stringmetadata: WebhookMetadatacategory: Stringupdated: DateTime<Utc>account_id: Stringuser_id: Stringcounterparty: CounterpartyOrNonescheme: Schemededupe_id: Stringoriginator: boolinclude_in_spending: boolcan_be_excluded_from_breakdown: boolcan_be_made_subscription: boolcan_split_the_bill: boolcan_add_to_tab: boolcan_match_transactions_in_categorization: boolamount_is_pending: boolparent_account_id: Stringcategories: Option<HashMap<String, i64>>declined: Option<Decline>attachments: ()atm_fees_detailed: ()fees: HashMap<(), ()>international: ()labels: ()extra: ExtraValuesThe value had extra fields that weren’t parsed into another field.